@@ -3,6 +3,7 @@ from jarvis.core.specie import (
     get_feats_hot_encoded,
     get_digitized_feats_hot_encoded,
     get_specie_data,
+    atomic_numbers_to_symbols
 )
 
 
@@ -18,3 +19,4 @@ def test_sp():
     dat = get_feats_hot_encoded()
     fat = get_digitized_feats_hot_encoded()
     x, y, z = get_specie_data()
+    x=atomic_numbers_to_symbols()
